#include <image.h>

Image::Image() {
	this->init();
}

Image::Image(string filename, int convertTo16) {
	this->init();
	this->load(filename, convertTo16);
}

Image::~Image() {
	if (this->loaded) {
		SDL_FreeSurface(this->image);
	}
}

void Image::init() {
	this->loaded=0;
}

int Image::load(string filename, int convertTo16) {
	// this is a library for gp2x, so 16 bit is forced
	SDL_Surface *tmp=IMG_Load(filename.c_str());

	if (tmp==NULL) {
		this->loaded=0;
		return this->loaded;
	}

	if (tmp->format->BitsPerPixel==16) {
		this->image=tmp;
	} else {
		if (convertTo16) {
			this->image=sdlCreateSurface(tmp->w,tmp->h);
			sdlLock(this->image);
			SDL_BlitSurface(tmp,NULL,this->image,NULL);
			sdlUnlock(this->image);
			SDL_FreeSurface(tmp);
		} else {
			this->image=tmp;
		}
	}
	this->loaded=1;
	return this->loaded;
}

void Image::blit(SDL_Surface *target, int x, int y) {
	SDL_Rect rect;
	rect.x=x;
	rect.y=y;
	SDL_BlitSurface(this->image, NULL, target, &rect);
}

void Image::blit(SDL_Surface *target, int x, int y, int offsetx, int offsety) {
	SDL_Rect dest;
	dest.x=x;
	dest.y=y;

	SDL_Rect source;
	source.x=offsetx;
	source.y=offsety;
	source.w=this->image->w-offsetx;
	source.h=this->image->h-offsety;

	SDL_BlitSurface(this->image, &source, target, &dest);
}

SDL_Surface *Image::getSDLSurface() {
	return this->image;
}

int Image::getWidth() {
	return this->image->w;
}

int Image::getHeight() {
	return this->image->h;
}
